@@ -203,6 +203,7 @@ class StaticMap:
         coords_d = {"EC": [-80, -75, 33.5, 36.55],
                     "NC":[-85, -75, 33.5, 37],
                     "USA":[-125, -66.5, 20, 50],
+                    "ESP":[-9, 4.2, 35, 45],
                     "World":[-179.99,179.99,-89.1,89.1]
                    }
         if isinstance(view, str):
@@ -288,7 +289,7 @@ class StaticMap:
         for country in countries:
             if country.attributes['ADM0_A3'] in self.nation_borders:
                 count_2plot.append(country.geometry)
-        self.ax.add_geometries(country.geometry, ccrs.PlateCarree(),
+        self.ax.add_geometries(count_2plot, ccrs.PlateCarree(),
                                       facecolor = cfeature.COLORS['land'],
                                       edgecolor = 'black')
         return
